from silk.tests.test_code_gen_curl import *
from silk.tests.test_collector import *
from silk.tests.test_dynamic_profiling import *
from silk.tests.test_execute_sql import *
from silk.tests.test_silky_middleware import *
from silk.tests.test_silky_profiler import *
from silk.tests.test_view_profiling import *
from silk.tests.test_view_requests import *
from silk.tests.test_end_points import *
from silk.tests.test_config_auth import *
from silk.tests.test_config_max_body_size import *
from silk.tests.test_config_meta import *
from silk.tests.test_view_sql_detail import *
from silk.tests.test_filters import *
from silk.tests.test_encoding import *